@@ -47,10 +47,7 @@ import berkeleydb
 from berkeleydb import db, dbutils, dbshelve, \
         hashopen, btopen, rnopen, dbobj
 
-if sys.version_info >= (3, 9):
-    from test.support.socket_helper import find_unused_port
-else:
-    from test.support import find_unused_port
+from test.support.socket_helper import find_unused_port
 
 if sys.version_info >= (3, 10):
     from test.support.os_helper import rmtree, unlink
@@ -156,13 +153,8 @@ class pathTest(unittest.TestCase):
         self.assertIsNotNone(path_dir)
         path_dir = path_dir.resolve()
         path_file = pathlib.Path(berkeleydb._db.__file__).resolve()
-        if sys.version_info >= (3, 9):
-            self.assertTrue(path_file.is_relative_to(path_dir),
-                    msg=f"Wrong library: '{path_file}' not in '{path_dir}'")
-        else:
-            path_dir = path_dir.as_posix()
-            path_file = path_file.as_posix()
-            self.assertEqual(path_dir, path_file[:len(path_dir)])
+        self.assertTrue(path_file.is_relative_to(path_dir),
+                        msg=f"Wrong library: '{path_file}' not in '{path_dir}'")
 
 
 def suite(module_prefix='', timing_check=None):
