@@ -92,7 +92,7 @@ class BasicTestCase(unittest.TestCase):
                 self.env.set_tx_timestamp(self._t)
                 self.env.set_flags(self.envsetflags, 1)
                 self.env.open(self.homeDir, self.envflags | db.DB_CREATE)
-                self.filename = "test"
+                self.filename = os.path.join(self.homeDir, 'test')
             # Yes, a bare except is intended, since we're re-raising the exc.
             except Exception:
                 rmtree(self.homeDir)
