@@ -1,5 +1,5 @@
 """
-Copyright (c) 2008-2023, Jesus Cea Avion <jcea@jcea.es>
+Copyright (c) 2008-2024, Jesús Cea Avión <jcea@jcea.es>
 All rights reserved.
 
 Redistribution and use in source and binary forms, with or without
@@ -14,7 +14,7 @@ are met:
     disclaimer in the documentation and/or other materials provided
     with the distribution.
 
-    3. Neither the name of Jesus Cea Avion nor the names of its
+    3. Neither the name of Jesús Cea Avión nor the names of its
     contributors may be used to endorse or promote products derived
     from this software without specific prior written permission.
 
